:root {
  color-scheme: light dark;
  color: var(--color-primary);
  background-color: var(--color-surface-01);

  font-synthesis: none;
  text-rendering: optimizeLegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

#root {
  margin: 0 auto;
  padding: 2rem;
  text-align: center;
  width: 100%;
  height: 100%;
}

body {
  display: flex;
  place-items: center;
  min-height: 100vh;
}
